@@ -269,7 +269,7 @@ static NSString *kDisplayedFirstSteps = @"Did we display the first steps tutoria
     NSIndexSet *indexSet = [allfiles indexesOfObjectsPassingTest:^BOOL(id obj, NSUInteger idx, BOOL *stop) {
        return ([obj rangeOfString:fileName].location != NSNotFound);
     }];
-    unsigned int count = indexSet.count;
+    NSUInteger count = indexSet.count;
     NSString *additionalFilePath;
     NSUInteger currentIndex = [indexSet firstIndex];
     for (unsigned int x = 0; x < count; x++) {
@@ -361,6 +361,15 @@ static NSString *kDisplayedFirstSteps = @"Did we display the first steps tutoria
         else if (file.isShowEpisode) {
             if (file.showEpisode.show.episodes.count < 2)
                 [_foundMedia addObject:file];
+
+            /* older MediaLibraryKit versions don't send a show name in a popular
+             * corner case. hence, we need to work-around here and force a reload
+             * afterwards as this could lead to the 'all my shows are gone' 
+             * syndrome (see #10435, #10464, #10432 et al) */
+            if (file.showEpisode.show.name.length == 0) {
+                file.showEpisode.show.name = NSLocalizedString(@"UNTITLED_SHOW", @"");
+                [self performSelector:@selector(updateViewContents) withObject:nil afterDelay:0.1];
+            }
         } else if (file.isAlbumTrack) {
             if (file.albumTrack.album.tracks.count < 2)
                 [_foundMedia addObject:file];
@@ -449,7 +458,7 @@ static NSString *kDisplayedFirstSteps = @"Did we display the first steps tutoria
             [media parse];
             [list addMedia:media];
         }
-        [(VLCAppDelegate*)[UIApplication sharedApplication].delegate openMediaList:list atIndex:[tracks indexOfObject:selectedObject]];
+        [(VLCAppDelegate*)[UIApplication sharedApplication].delegate openMediaList:list atIndex:(int)[tracks indexOfObject:selectedObject]];
     } else
         [self openMediaObject:selectedObject];
 }
@@ -562,7 +571,7 @@ static NSString *kDisplayedFirstSteps = @"Did we display the first steps tutoria
             file = [(MLAlbumTrack*)tracks[x] files].anyObject;
             [list addMedia:[VLCMedia mediaWithURL: [NSURL URLWithString:file.url]]];
         }
-        [(VLCAppDelegate*)[UIApplication sharedApplication].delegate openMediaList:list atIndex:[tracks indexOfObject:selectedObject]];
+        [(VLCAppDelegate*)[UIApplication sharedApplication].delegate openMediaList:list atIndex:(int)[tracks indexOfObject:selectedObject]];
     } else
         [self openMediaObject:selectedObject];
 }
